diff --git a/Makefile b/Makefile
index 3ce01e1..0931aed 100644
--- a/Makefile
+++ b/Makefile
@@ -1,4 +1,4 @@
-JAVA_HOME = /opt/jdk1.8
+JAVA_HOME = $(shell /usr/libexec/java_home)
 CC = gcc
 JAVA = java
 JAVAC = javac
@@ -21,10 +21,10 @@ native/pty/org_domterm_pty_PTY.h: domterm.jar
 PTY_COMMON_PARAMS = -fno-strict-aliasing -fPIC -W -Wall  -Wno-unused -Wno-parentheses -fno-omit-frame-pointer
 
 native/pty/pty.o: native/pty/pty.c native/pty/org_domterm_pty_PTY.h
-	$(CC) -O2 -ffast-math $(PTY_COMMON_PARAMS) -Inative/pty -I$(JAVA_HOME)/include -I$(JAVA_HOME)/include/linux -c $< -o $@
+	$(CC) -O2 -ffast-math $(PTY_COMMON_PARAMS) -Inative/pty -I$(JAVA_HOME)/include -I$(JAVA_HOME)/include/linux -I$(JAVA_HOME)/include/darwin -c $< -o $@
 
 native/pty/pty_fork.o: native/pty/pty_fork.c
-	$(CC) -O2 -ffast-math $(PTY_COMMON_PARAMS) -Inative/pty -I$(JAVA_HOME)/include -I$(JAVA_HOME)/include/linux -c $< -o $@
+	$(CC) -O2 -ffast-math $(PTY_COMMON_PARAMS) -Inative/pty -I$(JAVA_HOME)/include -I$(JAVA_HOME)/include/linux -I$(JAVA_HOME)/include/darwin -c $< -o $@
 
 libpty.so: native/pty/pty.o native/pty/pty_fork.o
 	$(CC) $(PTY_COMMON_PARAMS) -shared -o $@ $^
@@ -74,7 +74,7 @@ org/classes.stamp: $(DOMTERM_JAR_SOURCES)
 	touch org/classes.stamp
 
 tmp-repl.in: org/domterm/repl.html Makefile
-	sed -e '/domterm-core/i<style>' \
+	gsed -e '/domterm-core/i<style>' \
 	  -e '/domterm-default/a</style>' \
 	  -e 's|<link .*/style/\(.*\).css">|#include "style/\1.css"|' \
 	  -e '/<script type="text.javascript">/d' \
@@ -90,7 +90,7 @@ domterm.jar: org/classes.stamp terminal.js tmp-repl.in
 	rm -rf tmp-for-jar
 	mkdir tmp-for-jar
 	tar cf - org/domterm/*.class org/domterm/*/*.class | (cd tmp-for-jar; tar xf -)
-	cpp -traditional-cpp -P <tmp-repl.in >tmp-for-jar/org/domterm/repl.html
+	~/gcc/bin/cpp -traditional-cpp -P <tmp-repl.in >tmp-for-jar/org/domterm/repl.html
 	cd tmp-for-jar && \
 	  jar cmf ../domterm-jar-manifest ../domterm.jar org/domterm/*.class org/domterm/*/*.class org/domterm/repl.html 
 
@@ -108,7 +108,7 @@ DOC_IMAGES = \
 
 doc/DomTerm.xml: doc/DomTerm.texi
 	$(MAKEINFO) -I=doc --docbook doc/DomTerm.texi -o - | \
-	sed \
+	gsed \
 	-e 's|_002d|-|g' \
 	-e 's|<emphasis></emphasis>||' \
 	-e 's|<inlinemediaobject><imageobject><imagedata fileref="\(.*\)" format="\(.*\)"></imagedata></imageobject></inlinemediaobject>|<ulink url="\1"><inlinemediaobject><imageobject><imagedata fileref="\1" format="\2"></imagedata></imageobject></inlinemediaobject></ulink>|' \
diff --git a/native/pty/pty.c b/native/pty/pty.c
index e143ce0..112dc81 100644
--- a/native/pty/pty.c
+++ b/native/pty/pty.c
@@ -47,7 +47,33 @@
 #include <sys/ioctl.h>
 #endif
 
-extern void err_sys(const char *fmt, ...);
+//extern void err_sys(const char *fmt, ...);
+#include <errno.h>
+#include <stdarg.h>
+
+static void
+err_doit(int errnoflag, int error, const char *fmt, va_list ap)
+{
+    char    buf[8094];
+    vsnprintf(buf, 8094, fmt, ap);
+    if (errnoflag)
+        snprintf(buf+strlen(buf), 8094-strlen(buf), ": %s",
+    strerror(error));
+    strcat(buf, "\n");
+    fflush(stdout);     /* in case stdout and stderr are the same */
+    fputs(buf, stderr);
+    fflush(NULL);       /* flushes all stdio output streams */
+}
+
+void
+err_sys(const char *fmt, ...)
+{
+    va_list     ap;
+    va_start(ap, fmt);
+    err_doit(1, errno, fmt, ap);
+    va_end(ap);
+    exit(1);
+}
 
 int log_to_stderr = 1;
 #define MAXLINE 512
